==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/ColumnFilterConditionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
/**
 * @hidden
 */
export let ColumnFilterConditionDescriptionMetadata = /*@__PURE__*/ (() => {
    class ColumnFilterConditionDescriptionMetadata extends Base {
        static b(a) {
            if (ColumnFilterConditionDescriptionMetadata.a == null) {
                ColumnFilterConditionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ColumnFilterConditionDescriptionMetadata.c(ColumnFilterConditionDescriptionMetadata.a);
            }
            if (a.k(ColumnFilterConditionDescriptionMetadata.a)) {
                return;
            }
            a.ab(ColumnFilterConditionDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            ColumnFilterConditionDescriptionMetadata.b(a);
            a.ac("ColumnFilterCondition", ColumnFilterConditionDescriptionMetadata.a);
        }
    }
    ColumnFilterConditionDescriptionMetadata.$t = markType(ColumnFilterConditionDescriptionMetadata, 'ColumnFilterConditionDescriptionMetadata');
    ColumnFilterConditionDescriptionMetadata.a = null;
    return ColumnFilterConditionDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/ColumnFilterConditionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
/**
 * @hidden
 */
export let ColumnFilterConditionDescriptionMetadata = /*@__PURE__*/ (() => {
    class ColumnFilterConditionDescriptionMetadata extends Base {
        static b(a) {
            if (ColumnFilterConditionDescriptionMetadata.a == null) {
                ColumnFilterConditionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ColumnFilterConditionDescriptionMetadata.c(ColumnFilterConditionDescriptionMetadata.a);
            }
            if (a.k(ColumnFilterConditionDescriptionMetadata.a)) {
                return;
            }
            a.ac(ColumnFilterConditionDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            ColumnFilterConditionDescriptionMetadata.b(a);
            a.ad("ColumnFilterCondition", ColumnFilterConditionDescriptionMetadata.a);
        }
    }
    ColumnFilterConditionDescriptionMetadata.$t = markType(ColumnFilterConditionDescriptionMetadata, 'ColumnFilterConditionDescriptionMetadata');
    ColumnFilterConditionDescriptionMetadata.a = null;
    return ColumnFilterConditionDescriptionMetadata;
})();
